@@ -149,7 +149,8 @@ def test_nirspec_aperture_transforms(verbose=False, siaf=None):
         siaf = copy.deepcopy(siaf)
 
     labels = ['X', 'Y']
-    threshold = 0.2
+    #threshold = 0.2
+    threshold = 0.3
 
     from_frame = 'sci'
     to_frames = 'det gwa idl tel'.split()
@@ -176,7 +177,7 @@ def test_nirspec_aperture_transforms(verbose=False, siaf=None):
                     rx0 = getattr(gwa_aperture, 'XSciRef')
                     ry0 = getattr(gwa_aperture, 'YSciRef')
                     aperture.tilt = (ry0 - 0.002, rx0 - 0.01)
-                   
+
                 # test transformations
                 if verbose:
                     print('testing {} {} Tilt={}'.format(siaf.instrument, aper_name, aperture.tilt))
@@ -216,7 +217,8 @@ def test_nirspec_slit_transformations(verbose=False, siaf=None):
         siaf = copy.deepcopy(siaf)
 
     threshold = 0.010  # arc-seconds
-    pixel_threshold = 10 * threshold
+    #pixel_threshold = 10 * threshold
+    pixel_threshold = 0.3
 
     labels = ['X', 'Y']
     from_frame = 'sci'
@@ -313,4 +315,4 @@ def test_sci_det_consistency(siaf=None):
     assert_allclose(nrs2_fp4mimf.det_to_sci(2048, 2048), (1, 1), atol=absolute_tolerance)
     assert_allclose(nrs2_full.det_to_sci(2048, 2048), (1, 1), atol=absolute_tolerance)
     # assert nrs2_fp4mimf.det_to_sci(2048, 2048) == (1, 1)
-    # assert nrs2_full.det_to_sci(2048, 2048) == (1, 1)
\ No newline at end of file
+    # assert nrs2_full.det_to_sci(2048, 2048) == (1, 1)
